@@ -28,7 +28,7 @@ from odcs.server import conf
 
 log = getLogger(__name__)
 
-__all__ = ('publish',)
+__all__ = ("publish",)
 
 
 def publish(msgs):
@@ -45,10 +45,10 @@ def _umb_send_msg(msgs):
     from rhmsg.activemq.producer import AMQProducer
 
     config = {
-        'urls': conf.messaging_broker_urls,
-        'certificate': conf.messaging_cert_file,
-        'private_key': conf.messaging_key_file,
-        'trusted_certificates': conf.messaging_ca_cert,
+        "urls": conf.messaging_broker_urls,
+        "certificate": conf.messaging_cert_file,
+        "private_key": conf.messaging_key_file,
+        "trusted_certificates": conf.messaging_ca_cert,
     }
     with AMQProducer(**config) as producer:
         producer.through_topic(conf.messaging_topic)
@@ -62,23 +62,23 @@ def _umb_send_msg(msgs):
 def _fedora_messaging_send_msg(msgs):
     """Send message to fedora-messaging."""
     from fedora_messaging import api, config
+
     config.conf.setup_logging()
 
     for msg in msgs:
         # "event" is typically just "state-changed"
-        event = msg.get('event', 'event')
-        topic = "compose.%s" % event
+        event = msg.get("event", "event")
+        topic = "odcs.compose.%s" % event
 
         api.publish(api.Message(topic=topic, body=msg))
 
 
 def _get_messaging_backend():
-    if conf.messaging_backend == 'rhmsg':
+    if conf.messaging_backend == "rhmsg":
         return _umb_send_msg
-    elif conf.messaging_backend == 'fedora-messaging':
+    elif conf.messaging_backend == "fedora-messaging":
         return _fedora_messaging_send_msg
     elif conf.messaging_backend:
-        raise ValueError(
-            'Unknown messaging backend {0}'.format(conf.messaging_backend))
+        raise ValueError("Unknown messaging backend {0}".format(conf.messaging_backend))
     else:
         return None
