@@ -117,7 +117,7 @@ class RawPungiConfig(BasePungiConfig):
         # and override some variables.
         if self.raw_config_wrapper_conf_path:
             main_cfg_path = os.path.join(topdir, "raw_config.conf")
-            shutil.copy2(
+            shutil.copyfile(
                 self.raw_config_wrapper_conf_path, os.path.join(topdir, "pungi.conf")
             )
             self.apply_raw_config_wrapper_overrides(os.path.join(topdir, "pungi.conf"))
@@ -229,6 +229,7 @@ class PungiConfig(BasePungiConfig):
         modular_koji_tags=None,
         module_defaults_url=None,
         scratch_modules=None,
+        scratch_build_tasks=None,
     ):
         super(PungiConfig, self).__init__()
         self.release_name = release_name
@@ -247,6 +248,10 @@ class PungiConfig(BasePungiConfig):
         self.packages = packages or []
         self.builds = builds or []
         self.scratch_modules = scratch_modules.split(" ") if scratch_modules else []
+        self.scratch_build_tasks = (
+            scratch_build_tasks.split(" ") if scratch_build_tasks else []
+        )
+        self.pkgset_allow_reuse = True
 
         # Store results as list of strings, so it can be used by jinja2
         # templates.
@@ -351,7 +356,8 @@ class PungiConfig(BasePungiConfig):
             tmp_variant.add_arch(comps.Arch(arch))
         if self.source_type == PungiSourceType.MODULE:
             for module in self.source.split(" "):
-                tmp_variant.add_module(comps.Module(module))
+                if module:
+                    tmp_variant.add_module(comps.Module(module))
         elif self.source_type == PungiSourceType.KOJI_TAG:
             if self.packages:
                 tmp_variant.add_group(
@@ -486,6 +492,7 @@ class Pungi(object):
             "ci": "--ci",
             "nightly": "--nightly",
             "production": "--production",
+            "development": "--development",
         }
         compose_type = compose.compose_type or "test"
 
@@ -517,7 +524,7 @@ class Pungi(object):
         # If Compose Tracking Service is configured in the config file,
         # we skip the ComposeInfo creation completely and instead let
         # the Pungi to ask CTS to generate unique ComposeInfo.
-        if "cts_url" in conf and "cts_keytab" in conf:
+        if conf.get("cts_url") and conf.get("cts_keytab"):
             return compose.toplevel_dir
 
         ci = ComposeInfo()
@@ -581,7 +588,7 @@ class Pungi(object):
 
             # If Compose Tracking Service is configured in the config file,
             # we need to get the Compose ID from Pungi in separate thread.
-            if "cts_url" in pungi_conf and "cts_keytab" in pungi_conf:
+            if pungi_conf.get("cts_url") and pungi_conf.get("cts_keytab"):
                 compose_id_thread = ReadComposeIdThread(compose)
                 compose_id_thread.start()
 
