@@ -44,6 +44,7 @@ from odcs.server.api_utils import (
     filter_composes,
     validate_json_data,
     raise_if_input_not_allowed,
+    cors_header,
 )
 from odcs.server.auth import requires_role, login_required, has_role
 from odcs.server.auth import require_scopes
@@ -104,8 +105,9 @@ class ODCSAPI(MethodView):
         else:
             return conf.seconds_to_live
 
+    @cors_header()
     def get(self, id):
-        """ Returns ODCS composes.
+        """Returns ODCS composes.
 
         If ``id`` is set, only the ODCS compose defined by that ID is
         returned.
@@ -150,7 +152,7 @@ class ODCSAPI(MethodView):
     @require_scopes("renew-compose")
     @requires_role("allowed_clients")
     def patch(self, id):
-        """ Extends the compose expiration time or regenerates expired compose.
+        """Extends the compose expiration time or regenerates expired compose.
 
         :query number id: :ref:`ID<id>` of the compose to update/regenerate.
         :jsonparam number seconds_to_live: Number of seconds before the compoose expires.
@@ -259,7 +261,7 @@ class ODCSAPI(MethodView):
     @require_scopes("new-compose")
     @requires_role("allowed_clients")
     def post(self):
-        """ Creates new ODCS compose request.
+        """Creates new ODCS compose request.
 
         :jsonparam number seconds_to_live: Number of seconds before the compoose expires.
         :jsonparam list flags: List of :ref:`compose flags<flags>` defined as strings.
@@ -282,6 +284,7 @@ class ODCSAPI(MethodView):
         :jsonparam list source["koji_event"]: Number defining the :ref:`koji_event<koji_event>`.
         :jsonparam list source["modular_koji_tags"]: List defining the :ref:`modular_koji_tags<modular_koji_tags>`.
         :jsonparam list source["scratch_modules"]: List defining the :ref:`scratch_modules<scratch_modules>`.
+        :jsonparam list source["scratch_build_tasks"]: List defining the :ref:`scratch_build_tasks<scratch_build_tasks>`.
 
         :statuscode 200: Compose request created and returned.
         :statuscode 401: Request not in valid format.
@@ -320,11 +323,19 @@ class ODCSAPI(MethodView):
         source_type = PUNGI_SOURCE_TYPE_NAMES[source_type]
 
         source = []
-        if "source" in source_data:
+        if "source" in source_data and source_data["source"] != "":
             # Use list(set()) here to remove duplicate sources.
             source = list(set(source_data["source"].split(" ")))
 
-        if not source and source_type != PungiSourceType.BUILD:
+        scratch_modules = None
+        if "scratch_modules" in source_data:
+            scratch_modules = " ".join(source_data["scratch_modules"])
+
+        if (
+            not source
+            and source_type != PungiSourceType.BUILD
+            and not (source_type == PungiSourceType.MODULE and scratch_modules)
+        ):
             err = "No source provided for %s" % source_type
             log.error(err)
             raise ValueError(err)
@@ -447,9 +458,9 @@ class ODCSAPI(MethodView):
         elif module_defaults_url and module_defaults_commit:
             module_defaults = "%s %s" % (module_defaults_url, module_defaults_commit)
 
-        scratch_modules = None
-        if "scratch_modules" in source_data:
-            scratch_modules = " ".join(source_data["scratch_modules"])
+        scratch_build_tasks = None
+        if "scratch_build_tasks" in source_data:
+            scratch_build_tasks = " ".join(source_data["scratch_build_tasks"])
 
         label = data.get("label", None)
         compose_type = data.get("compose_type", "test")
@@ -496,6 +507,7 @@ class ODCSAPI(MethodView):
             target_dir=target_dir,
             scratch_modules=scratch_modules,
             parent_pungi_compose_ids=parent_pungi_compose_ids,
+            scratch_build_tasks=scratch_build_tasks,
         )
         db.session.add(compose)
         # Flush is needed, because we use `before_commit` SQLAlchemy event to
@@ -582,8 +594,9 @@ class ODCSAPI(MethodView):
 
 
 class AboutAPI(MethodView):
+    @cors_header()
     def get(self):
-        """ Returns information about this ODCS instance in JSON format.
+        """Returns information about this ODCS instance in JSON format.
 
         :resjson string version: The ODCS server version.
         :resjson string auth_backend: The name of authorization backend this
@@ -622,6 +635,7 @@ class Index(View):
 
 
 class MetricsAPI(MethodView):
+    @cors_header()
     def get(self):
         """
         Returns the Prometheus metrics.
