@@ -97,6 +97,24 @@ class TestBackend(ModelsBaseTest):
             ),
         )
 
+    @mock_mbs()
+    def test_resolve_compose_module_empty_source(self):
+        c = Compose.create(
+            db.session,
+            "me",
+            PungiSourceType.MODULE,
+            "",
+            COMPOSE_RESULTS["repository"],
+            3600,
+        )
+        db.session.commit()
+
+        resolve_compose(c)
+        db.session.commit()
+
+        c = db.session.query(Compose).filter(Compose.id == 1).one()
+        self.assertEqual(c.source, "")
+
     @mock_mbs()
     def test_resolve_compose_module_include_done_modules(self):
         c = Compose.create(
@@ -1316,9 +1334,11 @@ class TestGeneratePungiCompose(ModelsBaseTest):
     @patch("os.symlink")
     @patch("os.unlink")
     @patch("odcs.server.pungi.PungiLogs.get_config_dump")
+    @patch("odcs.server.backend._write_repo_file")
     def test_generate_pungi_compose_raw_config(
-        self, config_dump, unlink, symlink, makedirs
+        self, write_repo_file, config_dump, unlink, symlink, makedirs
     ):
+        self.is_cached.return_value = False
         config_dump.return_value = "fake\npungi\nconf\n"
         c = Compose.create(
             db.session,
@@ -1368,6 +1388,7 @@ class TestGeneratePungiCompose(ModelsBaseTest):
         unlink.assert_called_with(
             AnyStringWith("/test_composes/production/latest-compose-1")
         )
+        write_repo_file.assert_not_called()
 
 
 class TestValidatePungiCompose(ModelsBaseTest):
