@@ -364,6 +364,7 @@ class TestViews(ViewBaseTest):
             "scratch_modules": None,
             "toplevel_url": "http://localhost/odcs/odcs-%d" % data["id"],
             "parent_pungi_compose_ids": None,
+            "scratch_build_tasks": None,
         }
         self.assertEqual(data, expected_json)
 
@@ -1247,6 +1248,33 @@ class TestViews(ViewBaseTest):
             "User unknown not allowed to operate with compose with source_types=tag.",
         )
 
+    def test_submit_scratch_build_tasks(self):
+        with self.test_request_context(user="dev"):
+            flask.g.oidc_scopes = [
+                "{0}{1}".format(conf.oidc_base_namespace, "new-compose")
+            ]
+
+            rv = self.client.post(
+                "/api/1/composes/",
+                data=json.dumps(
+                    {
+                        "source": {
+                            "type": "module",
+                            "source": "testmodule:master",
+                            "scratch_build_tasks": [
+                                "123456",
+                                "123457",
+                            ],
+                        }
+                    }
+                ),
+            )
+            data = json.loads(rv.get_data(as_text=True))
+            self.assertEqual(
+                data["scratch_build_tasks"],
+                "123456 123457",
+            )
+
     def test_submit_build_scratch_modules(self):
         with self.test_request_context(user="dev"):
             flask.g.oidc_scopes = [
@@ -1269,6 +1297,38 @@ class TestViews(ViewBaseTest):
                 ),
             )
             data = json.loads(rv.get_data(as_text=True))
+            self.assertEqual(
+                data["source"],
+                "testmodule:master",
+            )
+            self.assertEqual(
+                data["scratch_modules"],
+                "foo:bar:20200806:abcdefgh fooo:bar:20200810:abcdefgh",
+            )
+
+    def test_submit_build_only_scratch_modules(self):
+        with self.test_request_context(user="dev"):
+            flask.g.oidc_scopes = [
+                "{0}{1}".format(conf.oidc_base_namespace, "new-compose")
+            ]
+
+            rv = self.client.post(
+                "/api/1/composes/",
+                data=json.dumps(
+                    {
+                        "source": {
+                            "type": "module",
+                            "source": "",
+                            "scratch_modules": [
+                                "foo:bar:20200806:abcdefgh",
+                                "fooo:bar:20200810:abcdefgh",
+                            ],
+                        }
+                    }
+                ),
+            )
+            data = json.loads(rv.get_data(as_text=True))
+            self.assertEqual(data["source"], "")
             self.assertEqual(
                 data["scratch_modules"],
                 "foo:bar:20200806:abcdefgh fooo:bar:20200810:abcdefgh",
@@ -1291,7 +1351,8 @@ class TestViews(ViewBaseTest):
             )
             data = json.loads(rv.get_data(as_text=True))
             self.assertEqual(
-                data["parent_pungi_compose_ids"], "Fedora-1-1 Fedora-2-2",
+                data["parent_pungi_compose_ids"],
+                "Fedora-1-1 Fedora-2-2",
             )
 
     def test_query_compose(self):
@@ -1300,6 +1361,7 @@ class TestViews(ViewBaseTest):
         self.assertEqual(data["id"], 1)
         self.assertEqual(data["source"], "testmodule:master")
         self.assertEqual(data["pungi_config_dump"], None)
+        self.assertEqual(resp.headers["Access-Control-Allow-Origin"], "*")
 
     def test_query_composes(self):
         resp = self.client.get("/api/1/composes/")
@@ -1762,6 +1824,7 @@ class TestViews(ViewBaseTest):
             "scratch_modules": None,
             "toplevel_url": "http://localhost/odcs/odcs-%d" % data["id"],
             "parent_pungi_compose_ids": None,
+            "scratch_build_tasks": None,
         }
         self.assertEqual(data, expected_json)
 
@@ -2093,6 +2156,7 @@ class TestViewsRawConfig(ViewBaseTest):
         self.assertEqual(c.source, "pungi_cfg#hash")
         self.assertEqual(c.label, "Beta-1.2")
         self.assertEqual(c.compose_type, "nightly")
+        self.assertEqual(c.json()["result_repofile"], "")
 
 
 class TestViewsCancelCompose(ViewBaseTest):
